import { Component, ChangeDetectionStrategy, Input, HostListener, ChangeDetectorRef } from '@angular/core';
import { DataTableComponent } from './data-table.component';
import { DataTableRowComponent } from './data-table-row.component';
import { stopPropagationIfExist } from '../utils/dom-utils';
var DataTableCellComponent = (function () {
    function DataTableCellComponent(dt, changeDetectorRef, rowComponent) {
        this.dt = dt;
        this.changeDetectorRef = changeDetectorRef;
        this.rowComponent = rowComponent;
    }
    DataTableCellComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.forceUpdateSubscription = this.rowComponent.forceUpdateEvent.subscribe(function (_) { return _this.forceUpdate(); });
    };
    DataTableCellComponent.prototype.onCellClick = function ($event) {
        var _this = this;
        var cellSelectedEventArg = {
            rowIndex: this.rowIndex,
            colIndex: this.colIndex,
            column: this.column,
            rowItem: this.rowItem,
            cellComponent: this,
            rowComponent: this.rowComponent
        };
        this.dt.onCellClick(cellSelectedEventArg);
        if (this.column.editable && this.editModel === 'cell') {
            stopPropagationIfExist($event);
            this.isCellEdit = true;
            this.documentClickubscription = this.dt.documentClickEvent.subscribe(function (_) { return _this.onFinishCellEdit(); });
            this.dt.onCellEditStart(cellSelectedEventArg);
            this.forceUpdate();
        }
    };
    DataTableCellComponent.prototype.forceUpdate = function () {
        this.changeDetectorRef.markForCheck();
    };
    DataTableCellComponent.prototype.onFinishCellEdit = function ($event) {
        if (this.editModel !== 'cell') {
            return;
        }
        this.isCellEdit = false;
        this.unSubscription(this.documentClickubscription);
        stopPropagationIfExist($event);
        this.dt.onCellEditEnd({
            rowIndex: this.rowIndex,
            colIndex: this.colIndex,
            column: this.column,
            rowItem: this.rowItem,
            cellComponent: this,
            rowComponent: this.rowComponent
        });
    };
    DataTableCellComponent.prototype.onCellDBClick = function ($event) {
        var cellSelectedEventArg = {
            rowIndex: this.rowIndex,
            colIndex: this.colIndex,
            column: this.column,
            rowItem: this.rowItem,
            cellComponent: this,
            rowComponent: this.rowComponent
        };
        this.dt.onCellDBClick(cellSelectedEventArg);
    };
    DataTableCellComponent.prototype.isCellEditEnable = function (column, rowItem) {
        if (this.editModel === 'cell') {
            return this.isCellEdit;
        }
        return this.isEditRow;
    };
    DataTableCellComponent.prototype.getCellValue = function (column, rowIndex, rowItem) {
        if (!column || !column.field) {
            return null;
        }
        if (column.field === '$index') {
            return rowIndex + 1;
        }
        return rowItem[column.field];
        /*
         * field with dot, like address.line1
         const fields = column.field.split('.');
         return fields.reduce((obj, field) => obj ? obj[field] : null, rowItem);
         */
    };
    DataTableCellComponent.prototype.getCellFormatValue = function (column, rowIndex, rowItem) {
        var cellValue = this.getCellValue(column, rowIndex, rowItem);
        if (column.field !== '$index' && column.formatter) {
            return column.formatter(cellValue);
        }
        return cellValue;
    };
    DataTableCellComponent.prototype.ngOnDestroy = function () {
        this.unSubscription(this.forceUpdateSubscription);
        this.unSubscription(this.documentClickubscription);
    };
    DataTableCellComponent.prototype.unSubscription = function (sbscription) {
        if (sbscription) {
            sbscription.unsubscribe();
            sbscription = null;
        }
    };
    return DataTableCellComponent;
}());
export { DataTableCellComponent };
DataTableCellComponent.decorators = [
    { type: Component, args: [{
                selector: 're-data-table-cell,[reDataTableCell]',
                template: "\n    <ng-container>\n      <ng-template *ngIf=\"!column.editable || !isCellEditEnable(column, rowItem)\"\n                [ngTemplateOutlet]=\"dataTableTemplates.getCellViewTemplate(column)\"\n                [ngOutletContext]=\"{\n                       rowIndex:rowIndex,\n                       colIndex:colIndex,\n                       column: column,\n                       rowItem:rowItem,\n                       cellItem: getCellValue(column, rowIndex, rowItem),\n                       cellValue:  getCellFormatValue(column, rowIndex, rowItem),\n                       $implicit: this,\n                       row: rowComponent\n                       }\">\n      </ng-template>\n\n      <ng-template *ngIf=\"column.editable && isCellEditEnable(column, rowItem)\"\n                [ngTemplateOutlet]=\"dataTableTemplates.getCellEditTemplate(column)\"\n                [ngOutletContext]=\"{\n                        rowIndex:rowIndex,\n                        colIndex:colIndex,\n                        column: column,\n                        rowItem: rowItem?.$editModel || rowItem,\n                        viewItem: rowItem,\n                        $implicit: this,\n                        row: rowComponent\n                        }\">\n      </ng-template>\n    </ng-container>\n  ",
                host: {
                    '[class]': 'column.cellClass ? column.cellClass : ""',
                },
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
DataTableCellComponent.ctorParameters = function () { return [
    { type: DataTableComponent, },
    { type: ChangeDetectorRef, },
    { type: DataTableRowComponent, },
]; };
DataTableCellComponent.propDecorators = {
    'rowIndex': [{ type: Input },],
    'colIndex': [{ type: Input },],
    'column': [{ type: Input },],
    'rowItem': [{ type: Input },],
    'dataTableTemplates': [{ type: Input },],
    'editModel': [{ type: Input },],
    'isEditRow': [{ type: Input },],
    'onCellClick': [{ type: HostListener, args: ['click', ['$event'],] },],
    'onCellDBClick': [{ type: HostListener, args: ['dbclick', ['$event'],] },],
};
//# sourceMappingURL=data-table-cell.component.js.map