import { Component, Input, Output, EventEmitter, Optional, Host, ContentChild } from '@angular/core';
import { PanelGroup } from './panel-group.model';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { stopPropagationIfExist } from '../utils/dom-utils';
import { PanelHeaderComponent } from './panel-header.component';
import { PanelBodyComponent } from './panel-body.component';
import { PanelFooterComponent } from './panel-footer.component';
var PanelComponent = (function () {
    function PanelComponent(panelGroup, rebirthUIConfig) {
        this.panelGroup = panelGroup;
        this.type = 'default';
        this.isCollapsed = false;
        this.close = new EventEmitter();
        this.collapse = new EventEmitter();
        this.type = rebirthUIConfig.panel.type;
        this.closable = rebirthUIConfig.panel.closable;
        this.collapsable = rebirthUIConfig.panel.collapsable;
    }
    PanelComponent.prototype.ngOnInit = function () {
        if (this.panelGroup) {
            this.panelGroup.$addItem(this);
        }
    };
    PanelComponent.prototype.onClose = function ($event) {
        stopPropagationIfExist($event);
        this.close.emit(this);
    };
    PanelComponent.prototype.onCollapse = function () {
        if (this.collapsable) {
            this.isCollapsed = !this.isCollapsed;
            this.collapse.emit(this.isCollapsed);
        }
    };
    PanelComponent.prototype.ngOnDestroy = function () {
        if (this.panelGroup) {
            this.panelGroup.$removeItem(this);
        }
    };
    return PanelComponent;
}());
export { PanelComponent };
PanelComponent.decorators = [
    { type: Component, args: [{
                selector: 're-panel,re-accordion-item',
                template: "\n    <div class=\"panel panel-{{type}} {{cssClass}}\" [ngClass]=\"{'panel-open': !isCollapsed}\">\n      <div class=\"panel-heading\" (click)=\"onCollapse()\" [ngStyle]=\"{cursor: collapsable ? 'pointer' :'inherit'}\"\n           *ngIf=\"panelHeader\">\n        <button type=\"button\" class=\"close\" *ngIf=\"closable\" aria-label=\"Close\" (click)=\"onClose($event)\">\n          <span aria-hidden=\"true\">&times;</span>\n        </button>\n        <ng-content select=\"re-panel-header,re-accordion-header\"></ng-content>\n      </div>\n      <div class=\"panel-body collapse\" [ngClass]=\"{in: !isCollapsed}\">\n        <ng-content select=\"re-panel-body,re-accordion-body\"></ng-content>\n      </div>\n      <div class=\"panel-footer\" *ngIf=\"panelFooter\">\n        <ng-content select=\"re-panel-footer,re-accordion-footer\"></ng-content>\n      </div>\n    </div>\n  ",
                exportAs: 'panel'
            },] },
];
/** @nocollapse */
PanelComponent.ctorParameters = function () { return [
    { type: PanelGroup, decorators: [{ type: Optional }, { type: Host },] },
    { type: RebirthNGConfig, },
]; };
PanelComponent.propDecorators = {
    'id': [{ type: Input },],
    'type': [{ type: Input },],
    'closable': [{ type: Input },],
    'collapsable': [{ type: Input },],
    'isCollapsed': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'close': [{ type: Output },],
    'collapse': [{ type: Output },],
    'panelHeader': [{ type: ContentChild, args: [PanelHeaderComponent,] },],
    'panelBody': [{ type: ContentChild, args: [PanelBodyComponent,] },],
    'panelFooter': [{ type: ContentChild, args: [PanelFooterComponent,] },],
};
//# sourceMappingURL=panel.component.js.map