import { Component, Input, Output, EventEmitter } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { TreeViewService } from './tree-view.service';
var TreeViewComponent = (function () {
    function TreeViewComponent(rebirthNGConfig, treeViewService) {
        this.treeViewService = treeViewService;
        this.checkable = false;
        this.lazyLoad = false;
        this.allowDraggable = false;
        this.allowMutipleSelected = false;
        this.nodeItemClicked = new EventEmitter();
        this.nodeItemDroped = new EventEmitter();
        this.nodeItemDbClicked = new EventEmitter();
        this.nodeItemCheckedChanged = new EventEmitter();
        this.nodeItemExpended = new EventEmitter();
        this.valueField = rebirthNGConfig.treeView.valueField;
        this.textField = rebirthNGConfig.treeView.textField;
        this.leafIcon = rebirthNGConfig.treeView.leafIcon;
        this.expendIcon = rebirthNGConfig.treeView.expendIcon;
        this.collapseIcon = rebirthNGConfig.treeView.collapseIcon;
        this.loadingIcon = rebirthNGConfig.treeView.loadingIcon;
    }
    TreeViewComponent.prototype.onNodeItemExpended = function (node) {
        this.nodeItemExpended.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemClicked = function (node) {
        if (!this.allowMutipleSelected) {
            if (this.selectNode && this.selectNode !== node) {
                this.selectNode.$$select = false;
            }
            this.selectNode = node;
        }
        this.nodeItemClicked.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemDbClicked = function (node) {
        this.nodeItemDbClicked.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemCheckedChanged = function (node) {
        this.nodeItemCheckedChanged.emit(node);
    };
    TreeViewComponent.prototype.onNodeItemDroped = function ($event) {
        var _this = this;
        var target = $event.target;
        if (!target) {
            return;
        }
        var source = $event.data.data.node;
        var sourceParent = $event.data.data.parent;
        if (sourceParent && sourceParent[this.valueField]) {
            var matchNode = this.getTreeNodeByValue(sourceParent[this.valueField]);
            if (matchNode) {
                matchNode.node.children = matchNode.node.children
                    .filter(function (nodeItem) { return nodeItem[_this.valueField] !== source[_this.valueField]; });
            }
        }
        else {
            if (this.treeData.length < 2) {
                return;
            }
            this.treeData = this.treeData.filter(function (nodeItem) { return nodeItem[_this.valueField] !== source[_this.valueField]; });
        }
        target.children = target.children || [];
        source.$$select = false;
        target.children.push(source);
        this.nodeItemDroped.emit($event);
    };
    TreeViewComponent.prototype.getSelectNodes = function () {
        return this.treeViewService.getSelectNodes(this.treeData);
    };
    TreeViewComponent.prototype.getCheckedNodes = function () {
        return this.treeViewService.getCheckedNodes(this.treeData);
    };
    TreeViewComponent.prototype.getMatchedItems = function (match) {
        return this.treeViewService.getMatchedItems(this.treeData, match);
    };
    TreeViewComponent.prototype.getFirstMatchedItem = function (match) {
        return this.treeViewService.getFirstMatchedItem(this.treeData, match);
    };
    TreeViewComponent.prototype.getTreeNodeByValue = function (value) {
        return this.treeViewService.getTreeNodeByValue(this.treeData, this.valueField, value);
    };
    TreeViewComponent.prototype.expendAllNodes = function () {
        return this.treeViewService.expendAllNodes(this.treeData);
    };
    TreeViewComponent.prototype.collapseAllNodes = function () {
        return this.treeViewService.collapseAllNodes(this.treeData);
    };
    TreeViewComponent.prototype.checkAllNodes = function () {
        return this.treeViewService.checkAllNodes(this.treeData);
    };
    TreeViewComponent.prototype.unCheckAllNodes = function () {
        return this.treeViewService.unCheckAllNodes(this.treeData);
    };
    TreeViewComponent.prototype.appendNodes = function (parentId, nodes) {
        return this.treeViewService.appendNodes(this.treeData, this.valueField, parentId, nodes);
    };
    TreeViewComponent.prototype.removeNode = function (value) {
        return this.treeViewService.removeNode(this.treeData, this.valueField, value);
    };
    return TreeViewComponent;
}());
export { TreeViewComponent };
TreeViewComponent.decorators = [
    { type: Component, args: [{
                selector: 're-tree-view',
                template: "\n    <re-tree-panel class=\"{{cssClass}}\" [treeData]=\"treeData\"\n                   [textField]=\"textField\"\n                   [valueField]=\"valueField\"\n                   [nodeCssClass]=\"nodeCssClass\"\n                   [iconField]=\"iconField\"\n                   [checkable]=\"checkable\"\n                   [lazyLoad]=\"lazyLoad\"\n                   [loadingIcon]=\"loadingIcon\"\n                   [loadChildren]=\"loadChildren\"\n                   [allowDraggable]=\"allowDraggable\"\n                   [nodeItemTemplate]=\"nodeItemTemplate\"\n                   [nodeItemToolbarTemplate]=\"nodeItemToolbarTemplate\"\n                   [leafIcon]=\"leafIcon\"\n                   [expendIcon]=\"expendIcon\"\n                   [collapseIcon]=\"collapseIcon\"\n                   [allowMutipleSelected]=\"allowMutipleSelected\"\n                   (nodeItemCheckedChanged)=\"onNodeItemCheckedChanged($event)\">\n    </re-tree-panel>\n  ",
                styles: ["\n\n  "],
                exportAs: 'treeView'
            },] },
];
/** @nocollapse */
TreeViewComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: TreeViewService, },
]; };
TreeViewComponent.propDecorators = {
    'treeData': [{ type: Input },],
    'valueField': [{ type: Input },],
    'textField': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'nodeCssClass': [{ type: Input },],
    'iconField': [{ type: Input },],
    'checkable': [{ type: Input },],
    'lazyLoad': [{ type: Input },],
    'loadingIcon': [{ type: Input },],
    'loadChildren': [{ type: Input },],
    'allowDraggable': [{ type: Input },],
    'allowMutipleSelected': [{ type: Input },],
    'nodeItemTemplate': [{ type: Input },],
    'nodeItemToolbarTemplate': [{ type: Input },],
    'leafIcon': [{ type: Input },],
    'expendIcon': [{ type: Input },],
    'collapseIcon': [{ type: Input },],
    'nodeItemClicked': [{ type: Output },],
    'nodeItemDroped': [{ type: Output },],
    'nodeItemDbClicked': [{ type: Output },],
    'nodeItemCheckedChanged': [{ type: Output },],
    'nodeItemExpended': [{ type: Output },],
};
//# sourceMappingURL=tree-view.component.js.map